===========
NestingTree
===========

.. currentmodule:: larch


.. autosummary::
    :toctree: generated/

    NestingTree

Methods
=======

.. autosummary::
    :toctree: generated/

    NestingTree.new_node
    NestingTree.add_node
    NestingTree.remove_node
    NestingTree.add_edge
    NestingTree.remove_edge
